import * as tslib_1 from "tslib";
import InputLabel from '@material-ui/core/InputLabel';
import Typography from '@material-ui/core/Typography';
import FieldCoreBase from '@react-form-fields/core/components/FieldCoreBase';
import ValidationContextRegister from '@react-form-fields/core/components/ValidationContextRegister';
import * as React from 'react';
import { getConfig } from '../../config';
import { WithStyles } from '../../decorators/withStyles';
import * as styles from './style.css';
let FieldHtml = class FieldHtml extends FieldCoreBase {
    constructor(props) {
        super(props);
        this.textareaRef = React.createRef();
        this.loadDependencies = async () => {
            if (!window.jQuery) {
                window.jQuery = window.$ = await import('jquery');
            }
            const { loadLocale, loadPlugins } = getConfig().trumbowyg;
            const [svgPath] = await Promise.all([
                import('trumbowyg/dist/ui/icons.svg'),
                import('trumbowyg/dist/trumbowyg.min.js'),
                import('trumbowyg/dist/ui/trumbowyg.min.css'),
            ]);
            await Promise.all([
                import('trumbowyg/dist/plugins/history/trumbowyg.history.min.js'),
                import('trumbowyg/dist/plugins/cleanpaste/trumbowyg.cleanpaste.min.js'),
                loadLocale ? loadLocale() : Promise.resolve(),
                ...(loadPlugins ? loadPlugins() : []),
            ]);
            return svgPath;
        };
        this.onChange = (value) => {
            if (this.props.value === value)
                return;
            getConfig().validationOn === 'onChange' && this.setState({ showError: true });
            this.props.onChange(value);
        };
        this.onBlur = (value) => {
            this.setState({ focused: false });
            this.props.onBlur && this.props.onBlur(null);
            if (this.props.value === value)
                return;
            getConfig().validationOn === 'onBlur' && this.setState({ showError: true });
            this.props.onChange(value);
        };
        this.onFocus = () => {
            this.setState({ focused: true });
        };
        this.dependenciesLoaded = this.loadDependencies();
    }
    async componentDidMount() {
        const svgPath = await this.dependenciesLoaded;
        this.instance = window.jQuery(this.textareaRef.current);
        this.instance.trumbowyg({
            svgPath,
            useComposition: false,
            autogrow: true,
            ...getConfig().trumbowyg.config
        }).on('tbwfocus', () => {
            this.onFocus();
        }).on('tbwchange', () => {
            this.onChange(this.instance.trumbowyg('html'));
        }).on('tbwblur', () => {
            this.onBlur(this.instance.trumbowyg('html'));
        });
        this.instance.trumbowyg('html', this.props.value);
    }
    componentDidUpdate() {
        if (!this.instance)
            return;
        this.instance.trumbowyg(this.props.disabled ? 'disable' : 'enable');
        if (this.instance.trumbowyg('html') !== this.props.value) {
            this.instance.trumbowyg('html', this.props.value);
        }
    }
    render() {
        const { focused } = this.state;
        const { classes, label, helperText, placeholder, disabled, value, ...otherProps } = this.props;
        return (React.createElement("div", { className: styles.component },
            React.createElement(ValidationContextRegister, { field: this }),
            React.createElement("div", { className: classes.label },
                React.createElement(InputLabel, { error: !!this.errorMessage, required: this.isRequired, focused: focused }, label),
                helperText || this.errorMessage ?
                    React.createElement(Typography, { variant: 'caption', color: this.errorMessage ? 'error' : null }, this.errorMessage || helperText)
                    : null),
            React.createElement("textarea", Object.assign({ ref: this.textareaRef, placeholder: placeholder, disabled: disabled }, otherProps))));
    }
};
FieldHtml = tslib_1.__decorate([
    WithStyles(theme => ({
        label: {
            display: 'block',
            marginBottom: 5
        },
        fullWrapper: {
            borderColor: theme.palette.type === 'light' ? 'rgba(0, 0, 0, 0.27)' : 'rgba(255, 255, 255, 0.7)',
        },
        editorWrapper: {
            ...theme.typography.body1
        }
    }))
], FieldHtml);
export default FieldHtml;
//# sourceMappingURL=index.js.map