import CircularProgress from '@material-ui/core/CircularProgress';
import FormControl from '@material-ui/core/FormControl';
import FormHelperText from '@material-ui/core/FormHelperText';
import InputAdornment from '@material-ui/core/InputAdornment';
import InputLabel from '@material-ui/core/InputLabel';
import MenuItem from '@material-ui/core/MenuItem/MenuItem';
import Select from '@material-ui/core/Select';
import FieldCoreBase from '@react-form-fields/core/components/FieldCoreBase';
import ValidationContextRegister from '@react-form-fields/core/components/ValidationContextRegister';
import * as React from 'react';
import { getConfig } from '../config';
export default class FieldSelect extends FieldCoreBase {
    constructor() {
        super(...arguments);
        this.onChange = (event) => {
            const value = event.target ? event.target.value : event;
            getConfig().validationOn === 'onChange' && this.setState({ showError: true });
            this.props.onChange(value === '' ? null : value);
        };
        this.onBlur = (e) => {
            this.props.onBlur && this.props.onBlur(e);
            getConfig().validationOn === 'onBlur' && this.setState({ showError: true });
        };
    }
    render() {
        const { value, options, children, label, loading, helperText, emptyOption, ...extra } = this.props;
        return (React.createElement(React.Fragment, null,
            React.createElement(ValidationContextRegister, { field: this }),
            React.createElement(FormControl, { margin: extra.margin || 'normal', fullWidth: true, error: !!this.errorMessage, variant: extra.variant },
                !!label &&
                    React.createElement(InputLabel, { required: this.isRequired, shrink: !!emptyOption || !!value, error: !!this.errorMessage, variant: extra.variant }, label),
                React.createElement(Select, Object.assign({}, {
                    fullWidth: true,
                    endAdornment: !loading ? null : (React.createElement(InputAdornment, { position: 'end' },
                        React.createElement(CircularProgress, { size: 20 }))),
                    ...extra,
                    displayEmpty: !!emptyOption,
                    value: !value && value !== 0 ? '' : value,
                    required: this.isRequired,
                    error: !!this.errorMessage,
                    onChange: this.onChange,
                    onBlur: this.onBlur,
                    submitted: null,
                    touched: null,
                    loading: null
                }),
                    emptyOption &&
                        React.createElement(MenuItem, { value: '' }, emptyOption),
                    (options || []).map(option => (React.createElement(MenuItem, { disabled: option.disabled, key: option.value, value: option.value }, option.label))),
                    children),
                !!(this.errorMessage || helperText) &&
                    React.createElement(FormHelperText, { error: !!this.errorMessage, variant: extra.variant }, this.errorMessage || helperText))));
    }
}
//# sourceMappingURL=Select.js.map