import CircularProgress from '@material-ui/core/CircularProgress/CircularProgress';
import InputAdornment from '@material-ui/core/InputAdornment/InputAdornment';
import TextField from '@material-ui/core/TextField/TextField';
import FieldCoreBase from '@react-form-fields/core/components/FieldCoreBase';
import ValidationContextRegister from '@react-form-fields/core/components/ValidationContextRegister';
import * as React from 'react';
import { getConfig } from '../config';
export default class FieldText extends FieldCoreBase {
    constructor() {
        super(...arguments);
        this.onChange = (event) => {
            const value = this.cleanValue(event.target ? event.target.value : event);
            getConfig().validationOn === 'onChange' && this.setState({ showError: true });
            this.props.onChange(value);
        };
        this.onBlur = (e) => {
            this.props.onBlur && this.props.onBlur(e);
            getConfig().validationOn === 'onBlur' && this.setState({ showError: true });
        };
    }
    getValue() {
        return this.mask.apply(this.props.value);
    }
    cleanValue(value) {
        return this.mask.clean(value);
    }
    render() {
        const value = this.getValue();
        const { loading, helperText, multiline, validationContext, ...extraProps } = this.props;
        return (React.createElement(React.Fragment, null,
            React.createElement(ValidationContextRegister, { field: this }),
            React.createElement(TextField, Object.assign({}, {
                fullWidth: true,
                margin: 'normal',
                rows: multiline ? 4 : null,
                ...extraProps,
                multiline,
                required: this.isRequired,
                value: (value === undefined || value === null ? '' : value).toString(),
                error: !!this.errorMessage,
                helperText: this.errorMessage || helperText,
                onChange: this.onChange,
                onBlur: this.onBlur,
                submitted: null,
                touched: null,
                loading: null
            }, { InputProps: {
                    endAdornment: !loading ? null : (React.createElement(InputAdornment, { position: 'end' },
                        React.createElement(CircularProgress, { color: 'secondary', size: 20 }))),
                    ...(extraProps.InputProps || {})
                } }))));
    }
}
//# sourceMappingURL=Text.js.map